@@ -37,3 +37,7 @@ class AristaEos(netmiko_devices.NetmikoSwitch):
             'no switchport mode trunk',
             'switchport trunk allowed vlan none'
         )
+
+        SAVE_CONFIGURATION = (
+            'write memory',
+        )
