@@ -45,6 +45,7 @@ class GenericSwitchDriver(api.MechanismDriver):
         LOG.info('Devices %s have been loaded', self.switches.keys())
         if not self.switches:
             LOG.error('No devices have been loaded')
+        self.warned_del_network = False
 
     def create_network_precommit(self, context):
         """Allocate resources for a new network.
@@ -75,10 +76,11 @@ class GenericSwitchDriver(api.MechanismDriver):
         network_id = network['id']
         provider_type = network['provider:network_type']
         segmentation_id = network['provider:segmentation_id']
+        physnet = network['provider:physical_network']
 
         if provider_type == 'vlan' and segmentation_id:
             # Create vlan on all switches from this driver
-            for switch_name, switch in self.switches.items():
+            for switch_name, switch in self._get_devices_by_physnet(physnet):
                 try:
                     switch.add_network(segmentation_id, network_id)
                 except Exception as e:
@@ -156,12 +158,28 @@ class GenericSwitchDriver(api.MechanismDriver):
         network = context.current
         provider_type = network['provider:network_type']
         segmentation_id = network['provider:segmentation_id']
+        physnet = network['provider:physical_network']
 
         if provider_type == 'vlan' and segmentation_id:
             # Delete vlan on all switches from this driver
-            for switch_name, switch in self.switches.items():
+            for switch_name, switch in self._get_devices_by_physnet(physnet):
                 try:
-                    switch.del_network(segmentation_id)
+                    # NOTE(mgoddard): The del_network method was modified to
+                    # accept the network ID. The switch object may still be
+                    # implementing the old interface, so retry on a TypeError.
+                    try:
+                        switch.del_network(segmentation_id, network['id'])
+                    except TypeError:
+                        if not self.warned_del_network:
+                            msg = (
+                                'The del_network device method should accept '
+                                'the network ID. Falling back to just the '
+                                'segmentation ID for %(device)s. This '
+                                'transitional support will be removed in the '
+                                'Rocky release')
+                            LOG.warn(msg, {'device': switch_name})
+                            self.warned_del_network = True
+                        switch.del_network(segmentation_id)
                 except Exception as e:
                     LOG.error("Failed to delete network %(net_id)s "
                               "on device: %(switch)s, reason: %(exc)s",
@@ -427,12 +445,19 @@ class GenericSwitchDriver(api.MechanismDriver):
                 ngs_mac_address=switch_id)
             if not switch:
                 return
+            network = context.network.current
+            physnet = network['provider:physical_network']
+            switch_physnets = switch._get_physical_networks()
+            if switch_physnets and physnet not in switch_physnets:
+                LOG.error("Cannot bind port %(port)s as device %(device)s is "
+                          "not on physical network %(physnet)",
+                          {'port_id': port['id'], 'device': switch_info,
+                           'physnet': physnet})
+                return
             port_id = local_link_information[0].get('port_id')
             segments = context.segments_to_bind
-            segmentation_id = segments[0].get('segmentation_id')
             # If segmentation ID is None, set vlan 1
-            if not segmentation_id:
-                segmentation_id = '1'
+            segmentation_id = segments[0].get('segmentation_id') or '1'
             provisioning_blocks.add_provisioning_component(
                 context._plugin_context, port['id'], resources.PORT,
                 GENERIC_SWITCH_ENTITY)
@@ -444,7 +469,7 @@ class GenericSwitchDriver(api.MechanismDriver):
             # Move port to network
             switch.plug_port_to_network(port_id, segmentation_id)
             LOG.info("Successfully bound port %(port_id)s in segment "
-                     " %(segment_id)s on device %(device)s",
+                     "%(segment_id)s on device %(device)s",
                      {'port_id': port['id'], 'device': switch_info,
                       'segment_id': segmentation_id})
             context.set_binding(segments[0][api.ID],
@@ -499,7 +524,8 @@ class GenericSwitchDriver(api.MechanismDriver):
         if not switch:
             return
         port_id = local_link_information[0].get('port_id')
-        segmentation_id = network.get('provider:segmentation_id', '1')
+        # If segmentation ID is None, set vlan 1
+        segmentation_id = network.get('provider:segmentation_id') or '1'
         LOG.debug("Unplugging port {port} on {switch_info} from vlan: "
                   "{segmentation_id}".format(
                       port=port_id,
@@ -515,6 +541,20 @@ class GenericSwitchDriver(api.MechanismDriver):
                        'switch': switch_info, 'exc': e})
             raise e
         LOG.info('Port %(port_id)s has been unplugged from network '
-                 ' %(net_id)s on device %(device)s',
+                 '%(net_id)s on device %(device)s',
                  {'port_id': port['id'], 'net_id': network['id'],
                   'device': switch_info})
+
+    def _get_devices_by_physnet(self, physnet):
+        """Generator yielding switches on a particular physical network.
+
+        :param physnet: Physical network to filter by.
+        :returns: Yields 2-tuples containing the name of the switch and the
+            switch device object.
+        """
+        for switch_name, switch in self.switches.items():
+            physnets = switch._get_physical_networks()
+            # NOTE(mgoddard): If the switch has no physical networks then
+            # follow the old behaviour of mapping all networks to it.
+            if not physnets or physnet in physnets:
+                yield switch_name, switch
